==> pvfs-1.3.2.tgz: pvfs-1.3.2/utils/pvstat.c <==
/*
 * pvstat.c copyright (c) 1997 Clemson University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Contact:  Rob Ross    rbross@parl.eng.clemson.edu
 *           Matt Cettei mcettei@parl.eng.clemson.edu
 */

/*/

/*
/* PVSTAT.C -	prints out information from metadata file
/*					Usage:  pvstat <filename>
/*
/*/

/*
 * $Log: pvstat.c,v $
 * Revision 1.3  1998/02/25 21:12:23  walt
 * replaced calls to open and read with syscall - so it will work right.
 *
 * Revision 1.2  1997/11/13 17:41:51  rbross
 * *** empty log message ***
 *
 * Revision 1.1  1997/11/13 17:36:26  rbross
 * Initial revision
 *
/*/

static char header[] = "$Header: /projects/pvfs/pvfs-working/utils/RCS/pvstat.c,v 1.3 1998/02/25 21:12:23 walt Exp $";

#include <stdio.h>
#include <fcntl.h>
#include <pvfs.h>
#include <sys/syscall.h>
#include <malloc.h>

main (int argc, char *argv[])
{
	int s, opt, opt2, i, fd, size;
	struct fmeta meta;
	
	if (argc < 2) exit(0);
	size 	= sizeof(fmeta);
	if ((fd  = syscall(SYS_open, argv[1], O_RDONLY)) < 0) {
		perror("open");
		exit(-1);
	}	
	if ((i = syscall(SYS_read, fd, &meta, size)) < 1) {
		perror("read");
		exit(-1);
	}	
	
	printf("inode:   %d\n",meta.u_stat.st_ino);
	printf("uid:     %d\n",meta.u_stat.st_uid);
	printf("pcount:  %d\n",meta.p_stat.pcount);
	printf("base:    %d\n",meta.p_stat.base);
	printf("ssize:   %d\n",meta.p_stat.ssize);
	printf("soff:    %d\n",meta.p_stat.soff);
	printf("bsize:   %d\n",meta.p_stat.bsize);
	close(fd);
}

==> pvfs-1.4.8-pre6.tgz: pvfs-1.4.8-pre6/utils/pvstat.c <==
/*
 * pvstat.c copyright (c) 1997 Clemson University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Contact:  Rob Ross    rbross@parl.eng.clemson.edu
 *           Matt Cettei mcettei@parl.eng.clemson.edu
 */

/*
 * PVSTAT.C -	prints out information from metadata file
 *					Usage:  pvstat <filename>
 *
 */

/*
 * $Log: pvstat.c,v $
 * Revision 1.3  2000/10/30 14:51:59  rbross
 * Took out all the glibc files, since we're not using them any more.
 * Removed instances of syscall() all over the place.
 *
 * Revision 1.2  2000/09/15 15:37:32  rbross
 * Cleaned up the utilities!  Wow!  Turned on warnings and strict
 * prototypes for a bit, cleaned up most everything.
 *
 * Revision 1.1.1.1  1999/08/10 17:11:31  rbross
 * Original 1.3.3 sources
 */

static char header[] = "$Header: /projects/cvsroot/pvfs/utils/pvstat.c,v 1.3 2000/10/30 14:51:59 rbross Exp $";

#include <stdio.h>
#include <fcntl.h>
#include <pvfs.h>
#include <malloc.h>

int main (int argc, char *argv[])
{
	int i, fd, size;
	struct fmeta meta;
	
	if (argc < 2) exit(0);

	size 	= sizeof(fmeta);
	if ((fd  = open(argv[1], O_RDONLY)) < 0) {
		perror("open");
		exit(-1);
	}	
	if ((i = read(fd, &meta, size)) < 1) {
		perror("read");
		exit(-1);
	}	
	
	printf("inode:   %ld\n",meta.u_stat.st_ino);
	printf("uid:     %d\n",meta.u_stat.st_uid);
	printf("pcount:  %d\n",meta.p_stat.pcount);
	printf("base:    %d\n",meta.p_stat.base);
	printf("ssize:   %d\n",meta.p_stat.ssize);
	printf("soff:    %d\n",meta.p_stat.soff);
	printf("bsize:   %d\n",meta.p_stat.bsize);
	close(fd);

	return 0;
}
